@@ -66,7 +66,7 @@ class GraphCRF(CRF):
 
             - 'qpbo' for QPBO + alpha expansion.
             - 'dai' for LibDAI bindings (which has another parameter).
-            - 'lp' for Linear Programming relaxation using GLPK.
+            - 'lp' for Linear Programming relaxation using cvxopt.
             - 'ad3' for AD3 dual decomposition.
 
         If None, ad3 is used if installed, otherwise lp.
